# Sponsors

vLLM is a community project. Our compute resources for development and testing are supported by the following organizations. Thank you for your support!

Please visit [vllm.ai/#sponsors](https://vllm.ai/#sponsors) to learn more.
